pub enum DocumentKind {
    Place,
    Model,
}
A document kind specifier.

Valid variants are the following:

  • Model
  • Place

Other variants are only to be used for logic internal to this crate.

Variants



Place



Model

Implementations

source

impl DocumentKind

source

pub fn from_extension(extension: impl AsRef<str>) -> Option<Self>

Try to convert a file extension into a valid document kind specifier.

Returns None if the file extension is not a canonical roblox file format extension.

source

pub fn from_path(path: impl AsRef<Path>) -> Option<Self>

Try to convert a file path into a valid document kind specifier.

Returns None if the file extension of the path is not a canonical roblox file format extension.

source

pub fn from_weak_dom(dom: &WeakDom) -> Option<Self>

Try to detect a document kind specifier from a weak dom.

Returns None if the given dom is empty and as such can not have its kind inferred.